%global pkgname ace

Name:           gap-pkg-%{pkgname}
Version:        5.2
Release:        0.2%{?dist}
Summary:        Advanced Coset Enumerator

License:        MIT
URL:            https://gap-packages.github.io/ace/
Source0:        https://github.com/gap-packages/ace/releases/download/v%{version}/%{pkgname}-%{version}.tar.gz

BuildRequires:  gap-devel
BuildRequires:  gcc
BuildRequires:  perl
BuildRequires:  tth

Requires:       gap-core

%description
The ACE package provides a mechanism to replace GAP's usual Todd-Coxeter
coset enumerator by ACE, so that functions that behind the scenes use
coset enumeration will use the ACE enumerator.  The ACE enumerator may
also be used explicitly; both non-interactively and interactively.
However the package is used, a plethora of options and strategies are
available to assist the user in avoiding incomplete coset enumerations.

%package doc
Summary:        Advanced Coset Enumerator documentation

%description doc
This package contains documentation for gap-pkg-%{pkgname}.

%prep
%setup -q -n %{pkgname}-%{version}

# Use the right compiler flags
sed -i "s|^CC =.*|CC = gcc $RPM_OPT_FLAGS $RPM_LD_FLAGS|" src/Makefile.in

# Remove a reference to an obsolete BiBTeX file
sed -i 's|\.\./\.\./\.\./doc/mrabbrev,||' doc/manual.tex

%build
# This is NOT an autoconf-generated script.  Do not use %%configure.
./configure %{_gap_dir}
make %{?_smp_mflags}

# Link to main GAP documentation
ln -s %{_gap_dir}/doc ../../doc
ln -s %{_gap_dir}/etc ../../etc
make doc
rm -f ../../{doc,etc}

# Avoid a filename collision
mv gap/CHANGES CHANGES.gap

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../%{pkgname}-%{version} %{buildroot}%{_gap_dir}/pkg/%{pkgname}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{CHANGES*,configure,LICENSE,Makefile*,README,doc/make_doc}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*.{aux,bbl,blg,brf,idx,ilg,ind,log,out,pnr,tex,toc}
rm -fr %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{doc/test,src,standalone-doc}

%check
cd tst
gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" << EOF 2>&1 | tee log
LoadPackage("ace");
Test("aceds.tst");
EOF
grep -Fvq fail log
rm -f log

%files
%doc CHANGES CHANGES.gap README
%license LICENSE
%{_gap_dir}/pkg/%{pkgname}/
%exclude %{_gap_dir}/pkg/%{pkgname}/doc
%exclude %{_gap_dir}/pkg/%{pkgname}/examples
%exclude %{_gap_dir}/pkg/%{pkgname}/htm
%exclude %{_gap_dir}/pkg/%{pkgname}/res-examples

%files doc
%doc standalone-doc/ace3001.ps
%license LICENSE
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%docdir %{_gap_dir}/pkg/%{pkgname}/examples
%docdir %{_gap_dir}/pkg/%{pkgname}/htm
%docdir %{_gap_dir}/pkg/%{pkgname}/res-examples

%changelog
* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 5.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Jul 29 2016 Jerry James <loganjerry@gmail.com> - 5.2-1
- Initial RPM
